package com.yunzhi.marketing.borker.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.borker.entity.BkBankCard;
import com.yunzhi.marketing.borker.service.IBkBankCardService;
import com.yunzhi.marketing.borker.vo.BorkerVO;
import com.yunzhi.marketing.common.CommConstant;
import com.yunzhi.marketing.common.StringUtils;
import com.yunzhi.marketing.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;


@Api(tags = "全民经纪人(新联康)")
@RestController
@RequestMapping("/api")
public class BorkerController  extends BaseController {

    @Autowired
    IBkBankCardService iBkBankCardService;


    @RequestMapping(value="/admin/borker",method= RequestMethod.GET)
    @ApiOperation(value="经纪人列表", notes = "经纪人列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getBorkerList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                      @ApiParam("手机号") @RequestParam(value ="phone", required = false) String phone,
                                      @ApiParam("姓名") @RequestParam(value ="name", required = false) String name,
                                      @ApiParam("推荐人") @RequestParam(value ="recommendPersonName", required = false) String recommendPersonName,
                                      @ApiParam("排序规则") @RequestParam(value ="sortOrder", defaultValue = "DESC") String sortOrder,
                                      @ApiParam("排序字段") @RequestParam(value ="sortField", defaultValue = "create_date") String sortField) throws Exception {

        IPage<BorkerVO> page = new Page<>(pageNum, pageSize);
        IPage<BorkerVO> result = iTaPersonService.getBorkerPage(page, name, phone, recommendPersonName, sortOrder, sortField);
        return ResponseBean.success(result);
    }


    @RequestMapping(value="/wx/bindBorker",method= RequestMethod.PUT)
    @ApiOperation(value="成为经纪人", notes = "成为经纪人", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean bindBorker(@ApiParam("经纪人信息") @RequestBody BorkerVO borkerVO,
                                   HttpServletRequest request) throws Exception {
        String personId = getPersonId(request);

        borkerVO.setPersonId(personId);
        borkerVO.setPersonType(CommConstant.PERSON_BORKER);

        TaPerson taPerson = new TaPerson();

        BeanUtils.copyProperties(borkerVO, taPerson, "bankCardList");
        taPerson.setTotalCommission(null);
        taPerson.setSettledCommission(null);
        taPerson.setUnsettledCommission(null);

        // 更新数据
        if (!iTaPersonService.updateById(taPerson)) {

            // 如果是有人推荐的, 那么需要给予推荐人一定的奖励
            if (!StringUtils.isEmpty(borkerVO.getRecommendAgent())) {
                // TODO
            }

            return ResponseBean.error("操作失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success(borkerVO);
    }
}
